# monday
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-9-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->
A monday.com Python Client Library

**Note:** This is a fork of the [original ProdPerfect/monday repository](https://github.com/ProdPerfect/monday) with additional enhancements and bug fixes.

For an overview of the Monday API, [click here](https://developer.monday.com/api-reference/docs).


#### Requirements
- Python >= 3.9

#### Getting started
`pip install mgmonday`

`mgmonday` is very simple to use -- take a look at the below example:
```python
from monday import MondayClient


monday = MondayClient('your token')

monday.items.create_item(board_id='12345678', group_id='today',  item_name='Do a thing')

```
### Additional Resources and Code Samples

- Read our [docs](https://monday.readthedocs.io/en/latest/) for a full list of available resources and methods for interacting with those resources.

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center"><a href="https://github.com/rhymiz"><img src="https://avatars.githubusercontent.com/u/7029352?v=4?s=100" width="100px;" alt="Lemi Boyce"/><br /><sub><b>Lemi Boyce</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=rhymiz" title="Code">💻</a> <a href="https://github.com/ProdPerfect/monday/issues?q=author%3Arhymiz" title="Bug reports">🐛</a> <a href="#maintenance-rhymiz" title="Maintenance">🚧</a></td>
      <td align="center"><a href="https://github.com/tonymorello"><img src="https://avatars.githubusercontent.com/u/7967400?v=4?s=100" width="100px;" alt="Tony Morello"/><br /><sub><b>Tony Morello</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=tonymorello" title="Code">💻</a></td>
      <td align="center"><a href="https://github.com/chdastolfo"><img src="https://avatars.githubusercontent.com/u/9096407?v=4?s=100" width="100px;" alt="chdastolfo"/><br /><sub><b>chdastolfo</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=chdastolfo" title="Code">💻</a> <a href="https://github.com/ProdPerfect/monday/issues?q=author%3Achdastolfo" title="Bug reports">🐛</a> <a href="https://github.com/ProdPerfect/monday/commits?author=chdastolfo" title="Documentation">📖</a> <a href="#maintenance-chdastolfo" title="Maintenance">🚧</a></td>
      <td align="center"><a href="https://github.com/lucioseki"><img src="https://avatars.githubusercontent.com/u/1480296?v=4?s=100" width="100px;" alt="Lucio Mitsuru Seki"/><br /><sub><b>Lucio Mitsuru Seki</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=lucioseki" title="Code">💻</a></td>
      <td align="center"><a href="https://github.com/yogeshnile"><img src="https://avatars.githubusercontent.com/u/54445087?v=4?s=100" width="100px;" alt="YOGESH NILE"/><br /><sub><b>YOGESH NILE</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=yogeshnile" title="Code">💻</a></td>
      <td align="center"><a href="https://github.com/spencersamuel7"><img src="https://avatars.githubusercontent.com/u/20449820?v=4?s=100" width="100px;" alt="spencersamuel7"/><br /><sub><b>spencersamuel7</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=spencersamuel7" title="Code">💻</a></td>
      <td align="center"><a href="https://github.com/albcl"><img src="https://avatars.githubusercontent.com/u/17050266?v=4?s=100" width="100px;" alt="Alb. C"/><br /><sub><b>Alb. C</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=albcl" title="Code">💻</a></td>
    </tr>
    <tr>
      <td align="center"><a href="https://github.com/pevner-p2"><img src="https://avatars.githubusercontent.com/u/45570949?v=4?s=100" width="100px;" alt="pevner-p2"/><br /><sub><b>pevner-p2</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=pevner-p2" title="Code">💻</a></td>
      <td align="center"><a href="https://github.com/t-a-y-l-o-r"><img src="https://avatars.githubusercontent.com/u/32030464?v=4?s=100" width="100px;" alt="Taylor Cochran"/><br /><sub><b>Taylor Cochran</b></sub></a><br /><a href="https://github.com/ProdPerfect/monday/commits?author=t-a-y-l-o-r" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

### Bug Reports
TBD
